@@ -1,5 +1,7 @@
 // SPDX-License-Identifier: (Apache-2.0 OR MIT)
 
+pub const INVALID_STR: &str = "str is not valid UTF-8: surrogates not allowed";
+
 macro_rules! is_type {
     ($obj_ptr:expr, $type_ptr:expr) => {
         unsafe { $obj_ptr == $type_ptr }
@@ -12,6 +14,30 @@ macro_rules! ob_type {
     };
 }
 
+macro_rules! is_class_by_type {
+    ($ob_type:expr, $type_ptr:ident) => {
+        unsafe { $ob_type == $type_ptr }
+    };
+}
+
+macro_rules! is_subclass_by_flag {
+    ($ob_type:expr, $flag:ident) => {
+        unsafe { (((*$ob_type).tp_flags & pyo3_ffi::$flag) != 0) }
+    };
+}
+
+macro_rules! is_subclass_by_type {
+    ($ob_type:expr, $type:ident) => {
+        unsafe {
+            (*($ob_type as *mut pyo3_ffi::PyTypeObject))
+                .ob_base
+                .ob_base
+                .ob_type
+                == $type
+        }
+    };
+}
+
 macro_rules! err {
     ($msg:expr) => {
         return Err(serde::ser::Error::custom($msg))
@@ -60,7 +86,7 @@ macro_rules! str_from_slice {
 macro_rules! reverse_pydict_incref {
     ($op:expr) => {
         unsafe {
-            if crate::ffi::_Py_IsImmortal($op) == 0 {
+            if pyo3_ffi::_Py_IsImmortal($op) == 0 {
                 debug_assert!(ffi!(Py_REFCNT($op)) >= 2);
                 (*$op).ob_refcnt.ob_refcnt -= 1;
             }
@@ -142,7 +168,7 @@ macro_rules! str_hash {
 #[cfg(Py_3_13)]
 macro_rules! pydict_contains {
     ($obj1:expr, $obj2:expr) => {
-        unsafe { pyo3_ffi::PyDict_Contains((*$obj1).tp_dict, $obj2) == 1 }
+        unsafe { pyo3_ffi::PyDict_Contains(pyo3_ffi::PyType_GetDict($obj1), $obj2) == 1 }
     };
 }
 
